@@ -3,32 +3,28 @@
 
 #include <gdkmmconfig.h>
 
-/* Defined when the -Dbuild-atkmm-api=true configure argument was given */
-#define GTKMM_ATKMM_ENABLED 1
-
 /* Define to omit deprecated API from gtkmm. */
 /* #undef GTKMM_DISABLE_DEPRECATED */
 
 /* Major version number of gtkmm. */
-#define GTKMM_MAJOR_VERSION 3
+#define GTKMM_MAJOR_VERSION 4
 
 /* Minor version number of gtkmm. */
-#define GTKMM_MINOR_VERSION 24
+#define GTKMM_MINOR_VERSION 2
 
 /* Micro version number of gtkmm. */
-#define GTKMM_MICRO_VERSION 8
+#define GTKMM_MICRO_VERSION 0
 
 /* Define when building gtkmm as a static library. */
 /* #undef GTKMM_STATIC_LIB */
 
-/* Enable DLL-specific stuff only when not building a static library  nor using gendef. */
-#if !defined(__CYGWIN__) && defined(_WIN32) && \
-    !defined(GTKMM_STATIC_LIB) && !defined(GTKMM_USE_GENDEF)
+/* Enable DLL-specific stuff only when not building a static library */
+#if !defined(__CYGWIN__) && defined(_WIN32) && !defined(GTKMM_STATIC_LIB)
 # define GTKMM_DLL 1
 #endif
 
 #ifdef GTKMM_DLL
-# if defined(GTKMM_BUILD)
+# if defined (GDKMM_BUILD) || defined(GTKMM_BUILD)
 #  define GTKMM_API __declspec(dllexport)
 # elif !defined (__GNUC__)
 #  define GTKMM_API __declspec(dllimport)
@@ -36,7 +32,7 @@
 #  define GTKMM_API
 # endif
 #else
-/* Build a static library or a non-native Windows library or gendef is used. */
+/* Build a static library or a non-native Windows library */
 # define GTKMM_API
 #endif /* GTKMM_DLL */
 
